abstractnn.affine\_engine
=========================

.. automodule:: abstractnn.affine_engine

   
   .. rubric:: Classes

   .. autosummary::
   
      AffineExpression
      AffineExpressionEngine
   